@@ -4,7 +4,7 @@ Module contains internal SQLToken that creates linked list
 from typing import Dict, List, Union
 
 import sqlparse.sql
-from sqlparse.tokens import Comment, Name, Number, Punctuation, Wildcard
+from sqlparse.tokens import Comment, Name, Number, Punctuation, Wildcard, Keyword
 
 from sql_metadata.keywords_lists import (
     KEYWORDS_BEFORE_COLUMNS,
@@ -41,6 +41,7 @@ class SQLToken:  # pylint: disable=R0902, R0904
             self.is_integer = tok.ttype is Number.Integer
             self.is_float = tok.ttype is Number.Float
             self.is_comment = tok.ttype is Comment or tok.ttype.parent == Comment
+            self.is_as_keyword = tok.ttype is Keyword and tok.normalized == "AS"
 
             self.is_left_parenthesis = str(tok) == "("
             self.is_right_parenthesis = str(tok) == ")"
@@ -62,6 +63,7 @@ class SQLToken:  # pylint: disable=R0902, R0904
         self.is_integer = False
         self.is_float = False
         self.is_comment = False
+        self.is_as_keyword = False
 
         self.is_left_parenthesis = False
         self.is_right_parenthesis = False
@@ -259,7 +261,7 @@ class SQLToken:  # pylint: disable=R0902, R0904
             (self.is_name or self.is_keyword)
             and self.last_keyword_normalized in TABLE_ADJUSTMENT_KEYWORDS
             and self.previous_token.normalized not in ["AS", "WITH"]
-            and self.normalized not in ["AS", "SELECT", "IF"]
+            and self.normalized not in ["AS", "SELECT", "IF", "SET", "WITH"]
         )
 
     @property
@@ -358,6 +360,15 @@ class SQLToken:  # pylint: disable=R0902, R0904
             or self.is_in_with_columns
         )
 
+    @property
+    def next_token_not_comment(self):
+        """
+        Property returning next non-comment token
+        """
+        if self.next_token and self.next_token.is_comment:
+            return self.next_token.next_token_not_comment
+        return self.next_token
+
     def is_constraint_definition_inside_create_table_clause(
         self, query_type: str
     ) -> bool:
